pub struct SharedModel { /* private fields */ }Expand description
Cloneable model handle used as the default for LanguageModelRequest.
Implements AISDK capability markers so the typed builder accepts prompts/tools
(runtime model selection — same idea as aisdk DynamicModel).
Implementations
Sourcepub fn wrap<M: LanguageModel>(model: M) -> Self
pub fn wrap<M: LanguageModel>(model: M) -> Self
Wrap any AISDK LanguageModel (provider or crate::FakeAi).